summaryrefslogtreecommitdiffstats
path: root/kcontrol/input
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:30:47 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:30:47 -0600
commitcc74f360bb40da3d79f58048f8e8611804980aa6 (patch)
treec4385d2c16b904757b1c8bb998a4aec6993373f7 /kcontrol/input
parent79b21d47bce1ee428affc97534cd8b257232a871 (diff)
downloadtdebase-cc74f360bb40da3d79f58048f8e8611804980aa6.tar.gz
tdebase-cc74f360bb40da3d79f58048f8e8611804980aa6.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'kcontrol/input')
-rw-r--r--kcontrol/input/core/themepage.cpp10
-rw-r--r--kcontrol/input/logitechmouse.cpp2
-rw-r--r--kcontrol/input/logitechmouse.h2
-rw-r--r--kcontrol/input/main.cpp4
-rw-r--r--kcontrol/input/mouse.cpp16
-rw-r--r--kcontrol/input/mouse.h6
-rw-r--r--kcontrol/input/xcursor/themepage.cpp12
7 files changed, 26 insertions, 26 deletions
diff --git a/kcontrol/input/core/themepage.cpp b/kcontrol/input/core/themepage.cpp
index ed3975fc9..dcef9b85e 100644
--- a/kcontrol/input/core/themepage.cpp
+++ b/kcontrol/input/core/themepage.cpp
@@ -93,7 +93,7 @@ void ThemePage::save()
bool whiteCursor = selectedTheme.right( 5 ) == "White";
bool largeCursor = selectedTheme.left( 5 ) == "Large";
- KConfig c( "kcminputrc" );
+ TDEConfig c( "kcminputrc" );
c.setGroup( "Mouse" );
c.writeEntry( "LargeCursor", largeCursor );
c.writeEntry( "WhiteCursor", whiteCursor );
@@ -116,7 +116,7 @@ void ThemePage::load( bool useDefaults )
{
bool largeCursor, whiteCursor;
- KConfig c( "kcminputrc" );
+ TDEConfig c( "kcminputrc" );
c.setReadDefaults( useDefaults );
@@ -179,14 +179,14 @@ void ThemePage::fixCursorFile()
// Run mkfontdir to update fonts.dir in that dir.
TDEGlobal::dirs()->addResourceType( "font", "share/fonts/" );
- KIO::mkdir( KURL::fromPathOrURL(TQDir::homeDirPath() + "/.fonts/kde-override") );
+ TDEIO::mkdir( KURL::fromPathOrURL(TQDir::homeDirPath() + "/.fonts/kde-override") );
TQString overrideDir = TQDir::homeDirPath() + "/.fonts/kde-override/";
KURL installedFont;
installedFont.setPath( overrideDir + "cursor.pcf.gz" );
if ( currentTheme == "SmallBlack" )
- KIO::NetAccess::del( installedFont, this );
+ TDEIO::NetAccess::del( installedFont, this );
else {
KURL source;
@@ -197,7 +197,7 @@ void ThemePage::fixCursorFile()
else if ( currentTheme == "SmallWhite" )
source.setPath( locate("data", "kcminput/cursor_small_white.pcf.gz") );
- KIO::NetAccess::file_copy( source, installedFont, -1, true );
+ TDEIO::NetAccess::file_copy( source, installedFont, -1, true );
}
TQString cmd = TDEGlobal::dirs()->findExe( "mkfontdir" );
diff --git a/kcontrol/input/logitechmouse.cpp b/kcontrol/input/logitechmouse.cpp
index 23defa614..39b8948ae 100644
--- a/kcontrol/input/logitechmouse.cpp
+++ b/kcontrol/input/logitechmouse.cpp
@@ -233,7 +233,7 @@ void LogitechMouse::applyChanges()
}
}
-void LogitechMouse::save(KConfig * /*config*/)
+void LogitechMouse::save(TDEConfig * /*config*/)
{
kdDebug() << "Logitech mouse settings not saved - not implemented yet" << endl;
}
diff --git a/kcontrol/input/logitechmouse.h b/kcontrol/input/logitechmouse.h
index 1eae2d60f..60780758a 100644
--- a/kcontrol/input/logitechmouse.h
+++ b/kcontrol/input/logitechmouse.h
@@ -52,7 +52,7 @@ public:
LogitechMouse( struct usb_device *usbDev, int mouseCapabilityFlags, TQWidget* parent = 0, const char* name = 0 );
~LogitechMouse();
void applyChanges();
- void save(KConfig *config);
+ void save(TDEConfig *config);
protected slots:
void setChannel1();
diff --git a/kcontrol/input/main.cpp b/kcontrol/input/main.cpp
index 439e5f676..0ab009ec9 100644
--- a/kcontrol/input/main.cpp
+++ b/kcontrol/input/main.cpp
@@ -41,14 +41,14 @@
extern "C"
{
- KDE_EXPORT KCModule *create_mouse(TQWidget *parent, const char *)
+ KDE_EXPORT TDECModule *create_mouse(TQWidget *parent, const char *)
{
return new MouseConfig(parent, "kcminput");
}
KDE_EXPORT void init_mouse()
{
- KConfig *config = new KConfig("kcminputrc", true, false); // Read-only, no globals
+ TDEConfig *config = new TDEConfig("kcminputrc", true, false); // Read-only, no globals
MouseSettings settings;
settings.load(config);
settings.apply(true); // force
diff --git a/kcontrol/input/mouse.cpp b/kcontrol/input/mouse.cpp
index ed43ef858..9253a1910 100644
--- a/kcontrol/input/mouse.cpp
+++ b/kcontrol/input/mouse.cpp
@@ -75,7 +75,7 @@
#undef Below
MouseConfig::MouseConfig (TQWidget * parent, const char *name)
- : KCModule(parent, name)
+ : TDECModule(parent, name)
{
@@ -483,7 +483,7 @@ void MouseConfig::load()
void MouseConfig::load( bool useDefaults )
{
- KConfig config( "kcminputrc", true );
+ TDEConfig config( "kcminputrc", true );
config.setReadDefaults( useDefaults );
@@ -516,7 +516,7 @@ void MouseConfig::load( bool useDefaults )
slotClick();
- KConfig ac("kaccessrc", true);
+ TDEConfig ac("kaccessrc", true);
ac.setGroup("Mouse");
mouseKeys->setChecked(ac.readBoolEntry("MouseKeys", false));
@@ -568,10 +568,10 @@ void MouseConfig::save()
settings->reverseScrollPolarity = tab1->cbScrollPolarity->isChecked();
settings->apply();
- KConfig config( "kcminputrc" );
+ TDEConfig config( "kcminputrc" );
settings->save(&config);
- KConfig ac("kaccessrc", false);
+ TDEConfig ac("kaccessrc", false);
ac.setGroup("Mouse");
@@ -593,7 +593,7 @@ void MouseConfig::save()
// restart kaccess
kapp->startServiceByDesktopName("kaccess");
- KCModule::changed(false);
+ TDECModule::changed(false);
}
@@ -624,7 +624,7 @@ void MouseConfig::slotHandedChanged(int val){
settings->m_handedNeedsApply = true;
}
-void MouseSettings::load(KConfig *config)
+void MouseSettings::load(TDEConfig *config)
{
int accel_num, accel_den, threshold;
double accel;
@@ -799,7 +799,7 @@ void MouseSettings::apply(bool force)
#endif
}
-void MouseSettings::save(KConfig *config)
+void MouseSettings::save(TDEConfig *config)
{
config->setGroup("Mouse");
config->writeEntry("Acceleration",accelRate);
diff --git a/kcontrol/input/mouse.h b/kcontrol/input/mouse.h
index bee04d5ea..809ac4817 100644
--- a/kcontrol/input/mouse.h
+++ b/kcontrol/input/mouse.h
@@ -62,8 +62,8 @@ class TQTabWidget;
class MouseSettings
{
public:
- void save(KConfig *);
- void load(KConfig *);
+ void save(TDEConfig *);
+ void load(TDEConfig *);
void apply(bool force=false);
public:
int num_buttons;
@@ -89,7 +89,7 @@ public:
#endif
};
-class MouseConfig : public KCModule
+class MouseConfig : public TDECModule
{
Q_OBJECT
public:
diff --git a/kcontrol/input/xcursor/themepage.cpp b/kcontrol/input/xcursor/themepage.cpp
index d716b9ab5..a0f0ef0cf 100644
--- a/kcontrol/input/xcursor/themepage.cpp
+++ b/kcontrol/input/xcursor/themepage.cpp
@@ -139,7 +139,7 @@ void ThemePage::save()
if ( currentTheme == selectedTheme )
return;
- KConfig c( "kcminputrc" );
+ TDEConfig c( "kcminputrc" );
c.setGroup( "Mouse" );
c.writeEntry( "cursorTheme", selectedTheme != "system" ? selectedTheme : TQString::null );
@@ -162,7 +162,7 @@ void ThemePage::load( bool useDefaults )
currentTheme = theme;
// Get the name of the theme TDE is configured to use
- KConfig c( "kcminputrc" );
+ TDEConfig c( "kcminputrc" );
c.setReadDefaults( useDefaults );
c.setGroup( "Mouse" );
currentTheme = c.readEntry( "cursorTheme", currentTheme );
@@ -221,7 +221,7 @@ void ThemePage::installClicked()
return;
TQString tmpFile;
- if ( !KIO::NetAccess::download( url, tmpFile, this ) ) {
+ if ( !TDEIO::NetAccess::download( url, tmpFile, this ) ) {
TQString text;
if ( url.isLocalFile() )
@@ -238,7 +238,7 @@ void ThemePage::installClicked()
KMessageBox::error( this, i18n( "The file %1 does not appear to be a valid "
"cursor theme archive.").arg( url.fileName() ) );
- KIO::NetAccess::removeTempFile( tmpFile );
+ TDEIO::NetAccess::removeTempFile( tmpFile );
}
@@ -257,7 +257,7 @@ void ThemePage::removeClicked()
// Delete the theme from the harddrive
KURL u;
u.setPath( themeInfo[ selectedTheme ]->path );
- KIO::del( u );
+ TDEIO::del( u );
// Remove the theme from the listview and from the themeinfo dict
delete listview->findItem( selectedTheme, DirColumn );
@@ -268,7 +268,7 @@ void ThemePage::removeClicked()
// Since it's possible to substitute cursors in a system theme by adding a local
// theme with the same name, we shouldn't remove the theme from the list if it's
// still available elsewhere. This could be solved by calling insertThemes() here,
// but since KIO::del() is an asynchronos operation, the theme we're deleting will
// be readded to the list again before KIO has removed it.
}
@@ -268,7 +268,7 @@ void ThemePage::removeClicked()
// theme with the same name, we shouldn't remove the theme from the list if it's
// still available elsewhere. This could be solved by calling insertThemes() here,
- // but since KIO::del() is an asynchronos operation, the theme we're deleting will
+ // but since TDEIO::del() is an asynchronos operation, the theme we're deleting will
// be readded to the list again before KIO has removed it.
}